@@ -1,8 +1,3 @@
-context ("sc-osm")
-
-test_all <- (identical (Sys.getenv ("MPADGE_LOCAL"), "true") |
-    identical (Sys.getenv ("GITHUB_WORKFLOW"), "test-coverage"))
-
 # Current names of SC objects as returned by osmdata:
 sc_names <- c (
     "nodes", "relation_members", "relation_properties",
