@@ -1,7 +1,5 @@
-context ("sf-osm")
-
-test_all <- (identical (Sys.getenv ("MPADGE_LOCAL"), "true") |
-    identical (Sys.getenv ("GITHUB_WORKFLOW"), "test-coverage"))
+test_all <- (identical (Sys.getenv ("MPADGE_LOCAL", "false"), "true") ||
+    identical (Sys.getenv ("GITHUB_WORKFLOW", "nope"), "test-coverage"))
 
 test_that ("multipolygon", {
     osm_multi <- test_path ("fixtures", "osm-multi.osm")
@@ -133,7 +131,7 @@ test_that ("non-valid key names", {
     q0 <- opq (bbox = c (1, 1, 5, 5))
     x <- osmdata_sf (q0, osm_multi)
 
-    k <- lapply (x[grep ("osm_", names(x))], function (f) {
+    k <- lapply (x [grep ("osm_", names (x))], function (f) {
         expect_true ("name:ca" %in% names (f))
     })
 })
@@ -141,15 +139,43 @@ test_that ("non-valid key names", {
 test_that ("clashes in key names", {
     osm_multi_key_clashes <- test_path ("fixtures", "osm-key_clashes.osm")
     q0 <- opq (bbox = c (1, 1, 5, 5))
-    expect_warning(
+    expect_warning (
         x <- osmdata_sf (q0, osm_multi_key_clashes),
         "Feature keys clash with id or metadata columns and will be renamed by "
     )
 
     expect_false (any (duplicated (names (x$osm_points))))
     # x$osm_points don't have osm_id column in tags TODO?
-    k <- lapply (x[grep ("osm_", names (x))[-1]], function (f) {
+    k <- lapply (x [grep ("osm_", names (x)) [-1]], function (f) {
         expect_false (any (duplicated (names (f))))
         expect_true (all (c ("osm_id", "osm_id.1") %in% names (f)))
     })
 })
+
+test_that ("duplicated column names", {
+    # https://github.com/ropensci/osmdata/issues/348
+    osm_ways <- test_path ("fixtures", "osm-ways.osm")
+
+    q0 <- opq (bbox = c (1, 1, 5, 5))
+    x0 <- osmdata_sf (q0, osm_ways)$osm_lines
+    expect_true ("boat" %in% names (x0))
+    x0_boat <- x0$boat [which (!is.na (x0$boat))]
+    expect_equal (x0_boat, "yes")
+
+    # Read those data and insert new node with duplicated name.
+    # This requires much less code read as text rather than xml:
+    x <- readLines (osm_ways)
+    i <- grep ("\"boat\"", x)
+    x_i <- gsub ("yes", "no", gsub ("boat", "Boat", x [i]))
+    x <- c (x [seq_len (i)], x_i, x [seq (i + 1L, length (x))])
+    ftmp <- tempfile (fileext = ".osm")
+    writeLines (x, ftmp)
+
+    # Note that XML parses capitals before lowercase, so "boat" is merged into
+    # "Boat"
+    x1 <- osmdata_sf (q0, ftmp)$osm_lines
+    expect_false ("boat" %in% names (x1))
+    expect_true ("Boat" %in% names (x1))
+    x1_boat <- x1$Boat [which (!is.na (x1$Boat))]
+    expect_equal (x1_boat, "no")
+})
