@@ -1,11 +1,12 @@
-context ("sp-osm")
-
 test_that ("multipolygon", {
     osm_multi <- test_path ("fixtures", "osm-multi.osm")
     x_sf <- sf::st_read (osm_multi, layer = "multipolygons", quiet = TRUE)
     x_sp <- as (x_sf, "Spatial")
     q0 <- opq (bbox = c (1, 1, 5, 5))
-    x <- osmdata_sp (q0, osm_multi)$osm_multipolygons
+    expect_warning (
+        x <- osmdata_sp (q0, osm_multi)$osm_multipolygons,
+        "Deprecated"
+    )
     # GDAL spits out a whole lot of generic field names, so first the
     # two have to be reduced to common fields.
     x <- x [, which (names (x) %in% names (x_sp))]
@@ -62,7 +63,10 @@ test_that ("multilinestring", {
     x_sf <- sf::st_read (osm_multi, layer = "multilinestrings", quiet = TRUE)
     x_sp <- as (x_sf, "Spatial")
     q0 <- opq (bbox = c (1, 1, 5, 5))
-    x <- osmdata_sp (q0, osm_multi)$osm_multilines
+    expect_warning (
+        x <- osmdata_sp (q0, osm_multi)$osm_multilines,
+        "Deprecated"
+    )
     x <- x [, which (names (x) %in% names (x_sp))]
     x_sp <- x_sp [, which (names (x_sp) %in% names (x))]
     rownames (slot (x, "data")) <- rownames (slot (x_sp, "data"))
@@ -98,7 +102,10 @@ test_that ("ways", {
     x_sf <- sf::st_read (osm_ways, layer = "lines", quiet = TRUE)
     x_sp <- as (x_sf, "Spatial")
     q0 <- opq (bbox = c (1, 1, 5, 5))
-    x <- osmdata_sp (q0, osm_ways)$osm_lines
+    expect_warning (
+        x <- osmdata_sp (q0, osm_ways)$osm_lines,
+        "Deprecated"
+    )
     x <- x [, which (names (x) %in% names (x_sp))]
     x_sp <- x_sp [, which (names (x_sp) %in% names (x))]
     np <- length (slot (slot (x, "lines") [[1]], "Lines"))
@@ -128,24 +135,27 @@ test_that ("ways", {
 test_that ("non-valid key names", {
     osm_multi <- test_path ("fixtures", "osm-multi.osm")
     q0 <- opq (bbox = c (1, 1, 5, 5))
-    x <- osmdata_sp (q0, osm_multi)
+    expect_warning (
+        x <- osmdata_sp (q0, osm_multi),
+        "Deprecated"
+    )
 
-    k <- lapply (x[grep ("osm_", names (x))], function (f) {
-        expect_true("name:ca" %in% names(f))
+    k <- lapply (x [grep ("osm_", names (x))], function (f) {
+        expect_true ("name:ca" %in% names (f))
     })
 })
 
 test_that ("clashes in key names", {
     osm_multi_key_clashes <- test_path ("fixtures", "osm-key_clashes.osm")
     q0 <- opq (bbox = c (1, 1, 5, 5))
-    expect_warning(
+    expect_warning (
         x <- osmdata_sp (q0, osm_multi_key_clashes),
         "Feature keys clash with id or metadata columns and will be renamed by "
     )
 
     expect_false (any (duplicated (names (x$osm_points))))
     # x$osm_points don't have osm_id column in tags TODO?
-    k <- lapply (x[grep ("osm_", names (x))[-1]], function (f) {
+    k <- lapply (x [grep ("osm_", names (x)) [-1]], function (f) {
         expect_false (any (duplicated (names (f))))
         expect_true (all (c ("osm_id", "osm_id.1") %in% names (f)))
     })
